#!/bin/sh
#
# Script for checking out and building RPM package in osc
#
# (C) 2010, suse-doc-team, Novell Inc.
# Distributable under GPLv2 or GPLv3
#
# upstream patches to https://svn.berlios.de/svnroot/repos/opensuse-docmaker/trunk/bin/buildsusedoc4osc.sh

# Default values:
# TODO: Maybe we should move it into a config file:
OBS_PROJECT="home:thomas-schraitle"
OBS_PACKAGE="susedoc"
OBS_USER="thomas-schraitle"
DEBUG=yes
DATE=$(date +%Y%m%d)
BERLIOS_URL="https://svn.berlios.de/svnroot/repos/opensuse-docmaker"
PACKAGEVERSION="4.2"
MESSAGE=""
COMMIT=0

# Rewrite SuSE-release into a shell script that is imported
py=/tmp/build-susedoc.py
cat > $py  << EOF
#!/usr/bin/python
import re

f = open("/etc/SuSE-release")
release = f.readline()
release.rsplit(' ', 2)
release=release.strip().rsplit(" ", 2)
# Remove any brackets:
try:
  release[2]=re.search("[(]?(\w*)[)]?", release[2]).groups()[0]
except:
  print "Something went wrong"
  exit(20)

x = open("/tmp/susedoc-system.sh", "w")
os=("OBS_OS=%s\n" % release[0], 
   "OBS_VERSION=%s\n" % release[1], 
   "OBS_ARCH=%s\n" % release[2] )
x.writelines(os)
x.close()
EOF

python $py
rm $py


#_=$(head -n1 /etc/SuSE-release)
#OBS_OS=$(expr match "$_" '\(^[a-zA-Z]*\)' )
##OBS_VERSION=$(expr match "$x" '^[a-zA-Z ]*\([0-9.]*\)')
#OBS_VERSION=$(cat /etc/SuSE-release | grep "VERSION" | sed 's/[^ ]* \?= \?//')
#OBS_ARCH=$(uname -m)

# Remove the brackets:
#OBS_ARCH=$(echo"$OBS_ARCH" | sed -e "s/(\([^)]*\))/\1/" )
#OBS_ARCH=$(expr match $OBS_ARCH  "(\([^)]*\))" )


debug()
{
  [ "$DEBUG" = "yes" ] && echo -e "\033[32m"$*"\033[m\017"
}

usage()
{
 echo -e "Usage: `basename $0`\n" \
  "OBS = OpenSUSE Build Server\n\n" \
  "Options:\n" \
  " -h, --help     Prints this output\n" \
  " -d, --debug    Switch on debug options\n" \
  " -t, --temp DIR
      Use existing temp directory in DIR from previous call\n" \
  " -p, --project PROJECTNAME
      Specifies the OBS project (default is '$OBS_PROJECT')\n" \
  " -a, --package PACKAGENAME
      Specifies the OBS package (default is '$OBS_PACKAGE')\n" \
  " -u, --user USERNAME
      Specifies the OBS user (default is '$OBS_USER')\n" \
  " -m, --message TEXT
      Specifies the message for the .changes file (don't open an editor)" \
  " also used as commit message\n" \
  " -c, --commit
      Activates the commit command after finished a successful build\n"
      
  exit 1
}

error()
{
  echo -e "\033[31m"$*"\033[m\017"
}

question()
{
while true; do
 echo -e "$1 [y|n]"
 read answer
 case "$answer" in
 [jJ]a|[yY]es|[yY])
   answer=y
   break ;;
 [nN]|[nN]o)
   answer=n
   break ;;
 esac
done
}


TEMP=$(getopt \
      -o hp:a:u:m:t:c \
  --long help,project:,package:,user:,message:,temp:,commit \
  -n "$0" -- "$@")
# Note the quotes around `$TEMP': they are essential!
eval set -- "$TEMP"


while true ; do
  case "$1" in
    -d|--debug)  DEBUG=yes ; shift 1 ;;
    -p|--project) OBS_PROJECT=$2 ; shift 2 ;;
    -u|--user) OBS_USER=$2 ; shift 2;;
    -a|--package) OBS_PACKAGE=$2 ; shift 2;;
    -m|--message) MESSAGE=$2 ; shift 2;;
    -t|--temp) TEMPDIR=$2 ; shift 2;;
    -c|--commit) COMMIT=1 ; shift ;;
#    -x|--debug)  set -x; shift 1 ;;
    -h|--help) usage ;;
    --) shift ; break ;;
    *) echo "Invalid Option ${1}"; break ;;
  esac
done



if [ "$TEMPDIR" = "" ]; then
TEMPDIR=$(mktemp --quiet -d /tmp/build-${OBS_PACKAGE}-XXXX )
fi

debug "OBS Project : $OBS_PROJECT"
debug "OBS Package : $OBS_PACKAGE"
debug "OBS User    : $OBS_USER"
debug "Message: $MESSAGE"

[ -e "/tmp/susedoc-system.sh" ] && source "/tmp/susedoc-system.sh"

debug "INFO: Detected the following Operating System:\n" \
      "_           OS: ${OBS_OS:?"<Empty>"}\n" \
      "_ Architecture: ${OBS_ARCH:?"<Empty>"}\n" \
      "_      Release: ${OBS_VERSION:?"<Empty>"}\n" \
      "---------------------------------------------------\n"


FILENAME=${OBS_PACKAGE}-${PACKAGEVERSION}_${DATE}.tar.bz2

##
pushd $TEMPDIR

## Step 1:
# We don't want to get .svn directories, therefor we use export:
debug "INFO: Exporting URL '$BERLIOS_URL'..."
debug "INFO: Using temp directory '$TEMPDIR'"
svn export --quiet $BERLIOS_URL/trunk ${OBS_PACKAGE}

## Step 2:
debug "INFO: Creating archive ..."
BZIP2=--best tar cjhf ${FILENAME} \
    --exclude-from=${OBS_PACKAGE}/bin/exclude-files.txt  ${OBS_PACKAGE}
rm -rf ${OBS_PACKAGE}

## Step 3:
debug "INFO: Checking out from OBS..."
osc co $OBS_PROJECT $OBS_PACKAGE

if [ $? -ne 0 ]; then
  res=$?
  error "osc checkout reported an error. Please check"
  exit $res
fi

# Check, if the option "checkout_no_colon" is set, directories
# are changed from home:USER to home/USER
COLON=$(grep "^checkout_no_colon" ~/.oscrc )
if [ "x$COLON" != "x" -a ${COLON/*=/} -eq 1 ]; then
OBS_PROJECT="home/$OBS_USER"
fi

# Memorize existing packages:
TARBZ=$(echo $OBS_PROJECT/$OBS_PACKAGE/*.tar.bz2)
# Needed to protect an new tarball from overwriting with an old one
for i in $TARBZ; do
  x=${i##*/}
  if [ "$x" != "$FILENAME" ]; then
    mv -v $i .
  fi
done
# Copy the new tarball into the OBS working copy:
cp -v ${FILENAME} $OBS_PROJECT/$OBS_PACKAGE


###
pushd $OBS_PROJECT/$OBS_PACKAGE

# Update to the new version:
sed -i "/^\%define _version/{s/\(.* \).*/\1$DATE/}" ${OBS_PACKAGE}.spec

if [ "$MESSAGE" = '' ]; then
  question "Would you like to create a Changelog entry for the .changes file?"
  if [ "$answer" = "y"  ]; then
    osc vc
  fi
 else
  debug "INFO: Modifying .changes file"
  osc vc --message "$MESSAGE"  ${OBS_PACKAGE}.changes
fi



debug "INFO: Building for ${OBS_OS}_${OBS_VERSION}..."
#
osc build ${OBS_OS}_${OBS_VERSION}

if [ $? -ne 0 ]; then
  res=$?
  error "osc reported an error. Please check"
  exit $res
else
  debug "INFO: Build was successful."
fi


if [ $COMMIT -gt 0 ]; then
  question "Would you like to commit it?"
  if [ "$answer" = "y" ]; then
    debug "INFO: Removing old tarball(s)..."
    for t in $TARBZ; do
        x=${t##*/}
        if [ "$x" != "$FILENAME" ]; then
          osc rm $x
        fi
    done
    osc add "${FILENAME}"
    debug "INFO: Committing..."
    osc ci --message "$MESSAGE"
    osc status
    TIME=$(date +%H%M%S)
    # Create a tag in the corresponding directory:
    debug "INFO: Tagging ${OBS_PACKAGE}-${PACKAGEVERSION}_${DATE}T${TIME}..."
    svn copy --message "$MESSAGE" \
      $BERLIOS_URL/trunk \
      $BERLIOS_URL/tags/obs/${OBS_PACKAGE}-${PACKAGEVERSION}_${DATE}T${TIME}
  fi
else
 debug "INFO: Changes NOT committed."
fi

popd # from $OBS_PROJECT/$OBS_PACKAGE
popd # from $TEMPDIR

# rm -rf $TEMP
debug "INFO: Using the directory '$TEMPDIR'"
debug "*** Finished. ***"

## EOF
