<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: xref.xsl 38284 2009-01-08 08:29:58Z toms $ -->
<!DOCTYPE xsl:stylesheet>

<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:fo="http://www.w3.org/1999/XSL/Format"
    xmlns:svg="http://www.w3.org/2000/svg">


<xsl:key name="chapters" match="chapter" use="@lang"/>


<xsl:template match="*/@id">
  <xsl:message>ID: "<xsl:value-of select="."/>"</xsl:message>
  <xsl:value-of select="."/>
</xsl:template>

<xsl:template match="xref" name="xref">
  <xsl:variable name="targets" select="key('id',@linkend)"/>
  <xsl:variable name="target" select="$targets[1]"/>
  <xsl:variable name="refelem" select="local-name($target)"/>
  <xsl:variable name="target.book" select="($target/ancestor-or-self::article|$target/ancestor-or-self::book)[1]"/>
  <xsl:variable name="this.book" select="(ancestor-or-self::article|ancestor-or-self::book)[1]"/>

  <!--<xsl:if test="$this.book/@id != $target.book/@id">
 <xsl:message>-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
 linkend:        <xsl:value-of select="@linkend"/>
 count(targets): <xsl:value-of select="count($targets)"/>
 target:         <xsl:value-of select="name($target)"/>
 refelem:        <xsl:value-of select="$refelem"/>
 $this.book/@id: <xsl:value-of select="$this.book/@id"/>
 $target.book/@id: <xsl:value-of select="$target.book/@id"/>
 $target/xml:base  <xsl:value-of select="$target/ancestor-or-self::*[1]/@xml:base"/>
 $target.book/title          "<xsl:value-of select="$target.book/title"/>"
 $target.book/bookinfo/title "<xsl:value-of select="$target.book/bookinfo/title"/>"
</xsl:message>
 </xsl:if>-->

  <xsl:call-template name="check.id.unique">
    <xsl:with-param name="linkend" select="@linkend"/>
  </xsl:call-template>

  <xsl:choose>
    <xsl:when test="(generate-id($target.book) = generate-id($this.book)) or
                     not(/set) or /article">
      <!-- An xref that stays inside the current book; use the defaults -->
       <xsl:apply-imports/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:choose>
        <xsl:when test="/set/@id=$rootid or
                        /article/@id=$rootid">
           <xsl:apply-imports/><!-- If we use the whole set, do the usual stuff -->
        </xsl:when>
        <xsl:otherwise>
          <!-- A reference into another book -->
          <xsl:variable name="target.chapandapp" 
                        select="$target/ancestor-or-self::chapter[@lang!='']
                                | $target/ancestor-or-self::appendix[@lang!='']"/>
          
          <xsl:if test="$warn.xrefs.into.diff.lang != 0 and 
                        $target.chapandapp/@lang != $this.book/@lang">
            <xsl:message>WARNING: The xref '<xsl:value-of 
            select="@linkend"/>' points to a chapter (id='<xsl:value-of 
              select="$target.chapandapp/@id"/>') with a different language than the main book.</xsl:message>
          </xsl:if>
          
         <xsl:apply-templates select="$target" mode="xref-to">
            <xsl:with-param name="referrer" select="."/>
            <xsl:with-param name="xrefstyle">
               <xsl:choose>
                  <xsl:when test="$refelem = 'chapter' or
                                  $refelem = 'appendix'">number</xsl:when>
                  <xsl:otherwise>nonumber</xsl:otherwise>
               </xsl:choose>
            </xsl:with-param>
         </xsl:apply-templates>
          
         <xsl:text> (</xsl:text>
         <xsl:if test="$target/self::sect1 or
                       $target/self::sect2 or
                       $target/self::sect3 or
                       $target/self::sect4">
         <!--<xsl:message> **** <xsl:value-of select="local-name($target)"/>
   <xsl:value-of select="$target/ancestor-or-self::chapter/title"/>
         </xsl:message>-->
               <xsl:apply-templates select="$target/ancestor-or-self::chapter |
                                            $target/ancestor-or-self::appendix |
                                            $target/ancestor-or-self::preface" mode="xref-to">
                  <xsl:with-param name="referrer" select="."/>
                  <!--<xsl:with-param name="xrefstyle">select: labelnumber title</xsl:with-param>-->
               </xsl:apply-templates>
               <xsl:text>, </xsl:text>
            </xsl:if>
         <xsl:text>&#x2191;</xsl:text>
          
          <xsl:choose>
            <xsl:when test="$refelem = 'article'">
              <xsl:apply-templates select="$target/title" mode="xref-to"/>
            </xsl:when>
            <xsl:when test="$refelem = 'book'">
              <xsl:apply-templates 
                select="$target.book" 
                mode="xref-to"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:apply-templates 
                select="$target.book" 
                mode="xref-to"/>
            </xsl:otherwise>
          </xsl:choose>
         <xsl:text>)</xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


<xsl:template match="article" mode="xref-to">
  <xsl:param name="referrer"/>
  <xsl:param name="xrefstyle"/>
  <xsl:param name="verbose" select="1"/>
  
  
  <xsl:apply-templates select=".|title/processing-instruction('suse')" mode="object.xref.markup">
    <xsl:with-param name="purpose" select="'xref'"/>
    <xsl:with-param name="xrefstyle" select="$xrefstyle"/>
    <xsl:with-param name="referrer" select="$referrer"/>
    <xsl:with-param name="verbose" select="$verbose"/>
  </xsl:apply-templates>
</xsl:template>

<xsl:template match="book" mode="xref-to">
  <xsl:param name="referrer"/>
  <xsl:param name="xrefstyle"/>
  <xsl:param name="verbose" select="1"/>

  
  <xsl:apply-templates select=".|(title/processing-instruction('suse')|bookinfo/title/processing-instruction('suse'))[1]" 
    mode="object.xref.markup">
    <xsl:with-param name="purpose" select="'xref'"/>
    <xsl:with-param name="xrefstyle" select="$xrefstyle"/>
    <xsl:with-param name="referrer" select="$referrer"/>
    <xsl:with-param name="verbose" select="$verbose"/>
  </xsl:apply-templates>
</xsl:template>


<!--  -->
<xsl:template match="processing-instruction('suse')" mode="xref-to">
    <xsl:param name="referrer"/>
    <xsl:param name="xrefstyle"/>
    <xsl:param name="verbose" select="1"/>
    
    <xsl:call-template name="suse-pi"/>
</xsl:template>
  
  
<xsl:template match="processing-instruction('suse')" mode="object.xref.markup">
    <xsl:param name="referrer"/>
    <xsl:param name="xrefstyle"/>
    <xsl:param name="verbose" select="1"/>
    
    <xsl:call-template name="suse-pi"/>
</xsl:template>
  

<!--  -->
<xsl:template match="*" mode="page.citation">
  <xsl:param name="id" select="'???'"/>

  <fo:inline>
    <xsl:call-template name="substitute-markup">
      <xsl:with-param name="template">
        <xsl:call-template name="gentext.template">
          <xsl:with-param name="name" select="'page.citation'"/>
          <xsl:with-param name="context" select="'xref'"/>
        </xsl:call-template>
      </xsl:with-param>
    </xsl:call-template>
  </fo:inline>
</xsl:template>

</xsl:stylesheet>